       MODULE INDX_MOD
       implicit none
       SAVE
       INTEGER :: IHE(1441), IHW(1441), IVE(1441), IVW(1441) 
C Substitua 500 pelo valor real de JM ou use ALLOCATABLE
       END MODULE INDX_MOD
