      FUNCTION TIMEF()
C>--------------------------------------------------------------------------------------------------
C> FUNCTION TIMEF
C>
C> FUNCTION: TIMEF - DESIGNED TO DUPLICATE TIMEF
C> PROGRAMMER: ?????   
C> ORG: ?????
C> DATE: ??-??-??
C> 
C> ABSTRACT:
C> DESIGNED TO DUPLICATE TIMEF
C>
C> PROGRAM HISTORY LOG:
C> 99-12-??  M. PYLE     - ORIGINATOR
C> 18-01-15  LUCCI       - MODERNIZATION OF THE CODE, INCLUDING:
C>                         * F77 TO F90/F95
C>                         * INDENTATION & UNIFORMIZATION CODE
C>                         * REPLACEMENT OF COMMONS BLOCK FOR MODULES
C>                         * DOCUMENTATION WITH DOXYGEN
C>                         * OPENMP FUNCTIONALITY
C>
C> INPUT ARGUMENT LIST:
C> NONE
C>
C> OUTPUT ARGUMENT LIST:
C> NONE
C>
C> INPUT/OUTPUT ARGUMENT LIST:
C> NONE
C>
C> USE MODULES: 
C>
C> DRIVER     : CHKOUT
C>              EBU
C>              INIT
C>              INITS
C>              PDTEDT
C>              QUILT
C>              TURBL
C>-------------------------------------------------------------------------------------------------- 
C
      REAL   (KIND=4), DIMENSION(2)                                  ::
     & ET
C
      REAL   (KIND=8)                                                ::
     & TIMEF
C
      TIMEF = ETIME(ET)
      TIMEF = TIMEF * 1.E3
C
      END FUNCTION TIMEF

